# OAuth

## V1

Methods:

- <code title="post /oauth/v1/token">client.oauth.v1.<a href="./src/ali_test_2/resources/oauth/v1.py">create_token</a>(\*\*<a href="src/ali_test_2/types/oauth/v1_create_token_params.py">params</a>) -> None</code>

# API

## V2

Types:

```python
from ali_test_2.types.api import (
    Category,
    CategoryType,
    V2AccessTokensResponse,
    V2RetrieveAppVersionsResponse,
    V2RetrieveCategoriesResponse,
)
```

Methods:

- <code title="post /api/v2/accessTokens">client.api.v2.<a href="./src/ali_test_2/resources/api/v2/v2.py">access_tokens</a>(\*\*<a href="src/ali_test_2/types/api/v2_access_tokens_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2_access_tokens_response.py">V2AccessTokensResponse</a></code>
- <code title="post /api/v2/login">client.api.v2.<a href="./src/ali_test_2/resources/api/v2/v2.py">login</a>(\*\*<a href="src/ali_test_2/types/api/v2_login_params.py">params</a>) -> None</code>
- <code title="get /api/v2/appVersions">client.api.v2.<a href="./src/ali_test_2/resources/api/v2/v2.py">retrieve_app_versions</a>() -> <a href="./src/ali_test_2/types/api/v2_retrieve_app_versions_response.py">V2RetrieveAppVersionsResponse</a></code>
- <code title="get /api/v2/categories">client.api.v2.<a href="./src/ali_test_2/resources/api/v2/v2.py">retrieve_categories</a>(\*\*<a href="src/ali_test_2/types/api/v2_retrieve_categories_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2_retrieve_categories_response.py">V2RetrieveCategoriesResponse</a></code>

### Carts

#### ID

Types:

```python
from ali_test_2.types.api.v2.carts import CurrencyObject, DeliveryMethod, Retailer
```

### Customers

Types:

```python
from ali_test_2.types.api.v2 import (
    Customer,
    MarketingConsentStatus,
    MarketingSubscriptionSource,
    PrivacyLaw,
    RewardsTierMap,
    CustomerBookmarkOrderingsResponse,
    CustomerDeletionRequestsResponse,
    CustomerRetrieveAvailableProfileImagesResponse,
    CustomerRetrieveRewardsSummaryResponse,
)
```

Methods:

- <code title="post /api/v2/customers">client.api.v2.customers.<a href="./src/ali_test_2/resources/api/v2/customers/customers.py">create</a>(\*\*<a href="src/ali_test_2/types/api/v2/customer_create_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customer.py">Customer</a></code>
- <code title="get /api/v2/customers/{customerId}">client.api.v2.customers.<a href="./src/ali_test_2/resources/api/v2/customers/customers.py">retrieve</a>(customer_id) -> <a href="./src/ali_test_2/types/api/v2/customer.py">Customer</a></code>
- <code title="put /api/v2/customers/{customerId}/accountConsents/{accountId}">client.api.v2.customers.<a href="./src/ali_test_2/resources/api/v2/customers/customers.py">update</a>(account_id, \*, customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customer_update_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/marketing_consent_status.py">MarketingConsentStatus</a></code>
- <code title="post /api/v2/customers/{customerId}/bookmarkOrderings">client.api.v2.customers.<a href="./src/ali_test_2/resources/api/v2/customers/customers.py">bookmark_orderings</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customer_bookmark_orderings_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customer_bookmark_orderings_response.py">CustomerBookmarkOrderingsResponse</a></code>
- <code title="post /api/v2/customers/{customerId}/deletionRequests">client.api.v2.customers.<a href="./src/ali_test_2/resources/api/v2/customers/customers.py">deletion_requests</a>(customer_id) -> <a href="./src/ali_test_2/types/api/v2/customer_deletion_requests_response.py">CustomerDeletionRequestsResponse</a></code>
- <code title="get /api/v2/customers/{customerId}/availableProfileImages">client.api.v2.customers.<a href="./src/ali_test_2/resources/api/v2/customers/customers.py">retrieve_available_profile_images</a>(customer_id) -> <a href="./src/ali_test_2/types/api/v2/customer_retrieve_available_profile_images_response.py">CustomerRetrieveAvailableProfileImagesResponse</a></code>
- <code title="get /api/v2/customers/{customerId}/rewardsSummary">client.api.v2.customers.<a href="./src/ali_test_2/resources/api/v2/customers/customers.py">retrieve_rewards_summary</a>(customer_id) -> <a href="./src/ali_test_2/types/api/v2/customer_retrieve_rewards_summary_response.py">CustomerRetrieveRewardsSummaryResponse</a></code>

#### Alerts

Types:

```python
from ali_test_2.types.api.v2.customers import Alert, TicketType, AlertListResponse
```

Methods:

- <code title="put /api/v2/customers/{customerId}/alerts">client.api.v2.customers.alerts.<a href="./src/ali_test_2/resources/api/v2/customers/alerts.py">create</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/alert_create_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/alert.py">Alert</a></code>
- <code title="get /api/v2/customers/{customerId}/alerts">client.api.v2.customers.alerts.<a href="./src/ali_test_2/resources/api/v2/customers/alerts.py">list</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/alert_list_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/alert_list_response.py">AlertListResponse</a></code>
- <code title="delete /api/v2/customers/{customerId}/alerts/{alertId}">client.api.v2.customers.alerts.<a href="./src/ali_test_2/resources/api/v2/customers/alerts.py">delete</a>(alert_id, \*, customer_id) -> None</code>

#### Bookmarks

Types:

```python
from ali_test_2.types.api.v2.customers import Bookmark, BookmarkUpdateResponse, BookmarkListResponse
```

Methods:

- <code title="put /api/v2/customers/{customerId}/bookmarks">client.api.v2.customers.bookmarks.<a href="./src/ali_test_2/resources/api/v2/customers/bookmarks.py">create</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/bookmark_create_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/bookmark.py">Bookmark</a></code>
- <code title="patch /api/v2/customers/{customerId}/bookmarks/{bookmarkId}">client.api.v2.customers.bookmarks.<a href="./src/ali_test_2/resources/api/v2/customers/bookmarks.py">update</a>(bookmark_id, \*, customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/bookmark_update_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/bookmark_update_response.py">BookmarkUpdateResponse</a></code>
- <code title="get /api/v2/customers/{customerId}/bookmarks">client.api.v2.customers.bookmarks.<a href="./src/ali_test_2/resources/api/v2/customers/bookmarks.py">list</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/bookmark_list_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/bookmark_list_response.py">BookmarkListResponse</a></code>
- <code title="delete /api/v2/customers/{customerId}/bookmarks/{bookmarkId}">client.api.v2.customers.bookmarks.<a href="./src/ali_test_2/resources/api/v2/customers/bookmarks.py">delete</a>(bookmark_id, \*, customer_id) -> None</code>

#### LotteryEntries

Types:

```python
from ali_test_2.types.api.v2.customers import (
    CustomerServiceInfo,
    LotteryEntry,
    MinifiedShow,
    SocialShareConfig,
    Theater,
    LotteryEntryAlohomoraResponse,
    LotteryEntryRetrieveLotteryEntriesResponse,
    LotteryEntryUpdateBatchResponse,
)
```

Methods:

- <code title="patch /api/v2/customers/{customerId}/lotteryEntries/{lotteryEntryId}">client.api.v2.customers.lottery_entries.<a href="./src/ali_test_2/resources/api/v2/customers/lottery_entries.py">update</a>(lottery_entry_id, \*, customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/lottery_entry_update_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/lottery_entry.py">LotteryEntry</a></code>
- <code title="post /api/v2/customers/{customerId}/lotteryEntries/alohomora">client.api.v2.customers.lottery_entries.<a href="./src/ali_test_2/resources/api/v2/customers/lottery_entries.py">alohomora</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/lottery_entry_alohomora_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/lottery_entry_alohomora_response.py">LotteryEntryAlohomoraResponse</a></code>
- <code title="post /api/v2/customers/{customerId}/lotteryEntries">client.api.v2.customers.lottery_entries.<a href="./src/ali_test_2/resources/api/v2/customers/lottery_entries.py">lottery_entries</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/lottery_entry_lottery_entries_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/lottery_entry.py">LotteryEntry</a></code>
- <code title="post /api/v2/customers/{customerId}/lotteryEntries/{lotteryEntryId}/resendConfirmationEmail">client.api.v2.customers.lottery_entries.<a href="./src/ali_test_2/resources/api/v2/customers/lottery_entries.py">resend_confirmation_email</a>(lottery_entry_id, \*, customer_id) -> None</code>
- <code title="get /api/v2/customers/{customerId}/lotteryEntries">client.api.v2.customers.lottery_entries.<a href="./src/ali_test_2/resources/api/v2/customers/lottery_entries.py">retrieve_lottery_entries</a>(customer_id) -> <a href="./src/ali_test_2/types/api/v2/customers/lottery_entry_retrieve_lottery_entries_response.py">LotteryEntryRetrieveLotteryEntriesResponse</a></code>
- <code title="patch /api/v2/customers/{customerId}/lotteryEntries/batch">client.api.v2.customers.lottery_entries.<a href="./src/ali_test_2/resources/api/v2/customers/lottery_entries.py">update_batch</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/lottery_entry_update_batch_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/lottery_entry_update_batch_response.py">LotteryEntryUpdateBatchResponse</a></code>

#### Offers

Types:

```python
from ali_test_2.types.api.v2.customers import Offer, OfferListResponse
```

Methods:

- <code title="get /api/v2/customers/{customerId}/offers/{offerId}">client.api.v2.customers.offers.<a href="./src/ali_test_2/resources/api/v2/customers/offers.py">retrieve</a>(offer_id, \*, customer_id) -> <a href="./src/ali_test_2/types/api/v2/customers/offer.py">Offer</a></code>
- <code title="patch /api/v2/customers/{customerId}/offers/{offerId}">client.api.v2.customers.offers.<a href="./src/ali_test_2/resources/api/v2/customers/offers.py">update</a>(offer_id, \*, customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/offer_update_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/offer.py">Offer</a></code>
- <code title="get /api/v2/customers/{customerId}/offers">client.api.v2.customers.offers.<a href="./src/ali_test_2/resources/api/v2/customers/offers.py">list</a>(customer_id) -> <a href="./src/ali_test_2/types/api/v2/customers/offer_list_response.py">OfferListResponse</a></code>

#### PaymentMethods

Types:

```python
from ali_test_2.types.api.v2.customers import (
    PaymentMethod,
    PaymentMethodRetrievePaymentMethodsResponse,
)
```

Methods:

- <code title="delete /api/v2/customers/{customerId}/paymentMethods/{paymentMethodId}">client.api.v2.customers.payment_methods.<a href="./src/ali_test_2/resources/api/v2/customers/payment_methods.py">delete</a>(payment_method_id, \*, customer_id) -> None</code>
- <code title="post /api/v2/customers/{customerId}/paymentMethods">client.api.v2.customers.payment_methods.<a href="./src/ali_test_2/resources/api/v2/customers/payment_methods.py">payment_methods</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/payment_method_payment_methods_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/payment_method.py">PaymentMethod</a></code>
- <code title="get /api/v2/customers/{customerId}/paymentMethods">client.api.v2.customers.payment_methods.<a href="./src/ali_test_2/resources/api/v2/customers/payment_methods.py">retrieve_payment_methods</a>(customer_id) -> <a href="./src/ali_test_2/types/api/v2/customers/payment_method_retrieve_payment_methods_response.py">PaymentMethodRetrievePaymentMethodsResponse</a></code>

#### ShowsReviews

Types:

```python
from ali_test_2.types.api.v2.customers import (
    CustomerShowReview,
    ShowsReviewRetrieveShowsReviewsResponse,
)
```

Methods:

- <code title="get /api/v2/customers/{customerId}/showsReviews">client.api.v2.customers.shows_reviews.<a href="./src/ali_test_2/resources/api/v2/customers/shows_reviews.py">retrieve_shows_reviews</a>(customer_id) -> <a href="./src/ali_test_2/types/api/v2/customers/shows_review_retrieve_shows_reviews_response.py">ShowsReviewRetrieveShowsReviewsResponse</a></code>
- <code title="put /api/v2/customers/{customerId}/showsReviews">client.api.v2.customers.shows_reviews.<a href="./src/ali_test_2/resources/api/v2/customers/shows_reviews.py">update_shows_reviews</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/shows_review_update_shows_reviews_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/customer_show_review.py">CustomerShowReview</a></code>

#### RushGrants

Types:

```python
from ali_test_2.types.api.v2.customers import RushGrant, RushGrantRetrieveRushGrantsResponse
```

Methods:

- <code title="get /api/v2/customers/{customerId}/rushGrants">client.api.v2.customers.rush_grants.<a href="./src/ali_test_2/resources/api/v2/customers/rush_grants.py">retrieve_rush_grants</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/rush_grant_retrieve_rush_grants_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/rush_grant_retrieve_rush_grants_response.py">RushGrantRetrieveRushGrantsResponse</a></code>
- <code title="post /api/v2/customers/{customerId}/rushGrants">client.api.v2.customers.rush_grants.<a href="./src/ali_test_2/resources/api/v2/customers/rush_grants.py">rush_grants</a>(customer_id, \*\*<a href="src/ali_test_2/types/api/v2/customers/rush_grant_rush_grants_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customers/rush_grant.py">RushGrant</a></code>

### Contentful

#### Webhook

Types:

```python
from ali_test_2.types.api.v2.contentful import WebhookHandlePublishArticleResponse
```

Methods:

- <code title="post /api/v2/contentful/webhook/handlePublishArticle">client.api.v2.contentful.webhook.<a href="./src/ali_test_2/resources/api/v2/contentful/webhook.py">handle_publish_article</a>(\*\*<a href="src/ali_test_2/types/api/v2/contentful/webhook_handle_publish_article_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/contentful/webhook_handle_publish_article_response.py">WebhookHandlePublishArticleResponse</a></code>

### Holds

Types:

```python
from ali_test_2.types.api.v2 import (
    Hold,
    PostHoldInputBody,
    PriceTypeSelection,
    Promotion,
    PyosHoldSeat,
    HoldListResponse,
    HoldRetrieveApplePaySessionResponse,
    HoldUpdateClearResponse,
)
```

Methods:

- <code title="post /api/v2/holds">client.api.v2.holds.<a href="./src/ali_test_2/resources/api/v2/holds.py">create</a>(\*\*<a href="src/ali_test_2/types/api/v2/hold_create_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/hold.py">Hold</a></code>
- <code title="get /api/v2/holds/{holdId}">client.api.v2.holds.<a href="./src/ali_test_2/resources/api/v2/holds.py">retrieve</a>(hold_id) -> object</code>
- <code title="patch /api/v2/holds/{holdId}">client.api.v2.holds.<a href="./src/ali_test_2/resources/api/v2/holds.py">update</a>(hold_id, \*\*<a href="src/ali_test_2/types/api/v2/hold_update_params.py">params</a>) -> object</code>
- <code title="get /api/v2/holds">client.api.v2.holds.<a href="./src/ali_test_2/resources/api/v2/holds.py">list</a>(\*\*<a href="src/ali_test_2/types/api/v2/hold_list_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/hold_list_response.py">HoldListResponse</a></code>
- <code title="delete /api/v2/holds/{holdId}">client.api.v2.holds.<a href="./src/ali_test_2/resources/api/v2/holds.py">delete</a>(hold_id) -> None</code>
- <code title="delete /api/v2/holds/{holdId}/ticketProtection">client.api.v2.holds.<a href="./src/ali_test_2/resources/api/v2/holds.py">delete_ticket_protection</a>(hold_id) -> object</code>
- <code title="delete /api/v2/holds/{holdId}/voucher">client.api.v2.holds.<a href="./src/ali_test_2/resources/api/v2/holds.py">delete_voucher</a>(hold_id) -> object</code>
- <code title="get /api/v2/holds/{holdId}/applePaySession">client.api.v2.holds.<a href="./src/ali_test_2/resources/api/v2/holds.py">retrieve_apple_pay_session</a>(hold_id) -> <a href="./src/ali_test_2/types/api/v2/hold_retrieve_apple_pay_session_response.py">HoldRetrieveApplePaySessionResponse</a></code>
- <code title="patch /api/v2/holds/{holdId}/clear">client.api.v2.holds.<a href="./src/ali_test_2/resources/api/v2/holds.py">update_clear</a>(hold_id) -> <a href="./src/ali_test_2/types/api/v2/hold_update_clear_response.py">HoldUpdateClearResponse</a></code>

### Locations

Types:

```python
from ali_test_2.types.api.v2 import (
    CurrencyCode,
    Location,
    LocationListResponse,
    LocationRetrieveGeolocationResponse,
    LocationRetrieveGeosegmentResponse,
    LocationRetrievePrivacyLawResponse,
)
```

Methods:

- <code title="get /api/v2/locations/{id}">client.api.v2.locations.<a href="./src/ali_test_2/resources/api/v2/locations.py">retrieve</a>(id) -> <a href="./src/ali_test_2/types/api/v2/location.py">Location</a></code>
- <code title="get /api/v2/locations">client.api.v2.locations.<a href="./src/ali_test_2/resources/api/v2/locations.py">list</a>() -> <a href="./src/ali_test_2/types/api/v2/location_list_response.py">LocationListResponse</a></code>
- <code title="get /api/v2/locations/geolocation">client.api.v2.locations.<a href="./src/ali_test_2/resources/api/v2/locations.py">retrieve_geolocation</a>() -> <a href="./src/ali_test_2/types/api/v2/location_retrieve_geolocation_response.py">LocationRetrieveGeolocationResponse</a></code>
- <code title="get /api/v2/locations/geosegment">client.api.v2.locations.<a href="./src/ali_test_2/resources/api/v2/locations.py">retrieve_geosegment</a>(\*\*<a href="src/ali_test_2/types/api/v2/location_retrieve_geosegment_params.py">params</a>) -> str</code>
- <code title="get /api/v2/locations/privacyLaw">client.api.v2.locations.<a href="./src/ali_test_2/resources/api/v2/locations.py">retrieve_privacy_law</a>(\*\*<a href="src/ali_test_2/types/api/v2/location_retrieve_privacy_law_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/location_retrieve_privacy_law_response.py">LocationRetrievePrivacyLawResponse</a></code>

### Notifications

Types:

```python
from ali_test_2.types.api.v2 import NotificationValidatePricingResponse
```

Methods:

- <code title="post /api/v2/notifications">client.api.v2.notifications.<a href="./src/ali_test_2/resources/api/v2/notifications.py">create</a>() -> None</code>
- <code title="delete /api/v2/notifications">client.api.v2.notifications.<a href="./src/ali_test_2/resources/api/v2/notifications.py">delete_all</a>() -> None</code>
- <code title="post /api/v2/notifications/validatePricing">client.api.v2.notifications.<a href="./src/ali_test_2/resources/api/v2/notifications.py">validate_pricing</a>(\*\*<a href="src/ali_test_2/types/api/v2/notification_validate_pricing_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/notification_validate_pricing_response.py">NotificationValidatePricingResponse</a></code>

### Orders

Types:

```python
from ali_test_2.types.api.v2 import (
    AddOns,
    Barcode,
    CustomerCareOrder,
    EarnedRewardsSummary,
    EticketDeliveryTime,
    Order,
    PriceItem,
    SeatsInfo,
    Ticket,
    TicketProtectionSummary,
    Voucher,
    OrderRetrieveResponse,
    OrderListResponse,
    OrderReissueTicketResponse,
    OrderRetrieveApplePassesResponse,
    OrderRetrieveGooglePassesResponse,
    OrderTicketProtectionRedemptionResponse,
)
```

Methods:

- <code title="post /api/v2/orders">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">create</a>(\*\*<a href="src/ali_test_2/types/api/v2/order_create_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/order.py">Order</a></code>
- <code title="get /api/v2/orders/byHoldId/{holdId}">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">retrieve</a>(hold_id, \*\*<a href="src/ali_test_2/types/api/v2/order_retrieve_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/order_retrieve_response.py">OrderRetrieveResponse</a></code>
- <code title="patch /api/v2/orders/{id}">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">update</a>(id, \*\*<a href="src/ali_test_2/types/api/v2/order_update_params.py">params</a>) -> object</code>
- <code title="get /api/v2/orders">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">list</a>(\*\*<a href="src/ali_test_2/types/api/v2/order_list_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/order_list_response.py">OrderListResponse</a></code>
- <code title="post /api/v2/orders/{id}/assignedCustomers">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">assigned_customers</a>(id, \*\*<a href="src/ali_test_2/types/api/v2/order_assigned_customers_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/order.py">Order</a></code>
- <code title="post /api/v2/orders/{confirmationNumber}/initiateTransfer">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">initiate_transfer</a>(confirmation_number) -> None</code>
- <code title="post /api/v2/orders/{id}/refundVoucher">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">refund_voucher</a>(id, \*\*<a href="src/ali_test_2/types/api/v2/order_refund_voucher_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customer_care_order.py">CustomerCareOrder</a></code>
- <code title="post /api/v2/orders/{id}/reissueTicket">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">reissue_ticket</a>(id) -> str</code>
- <code title="post /api/v2/orders/{id}/relist">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">relist</a>(id, \*\*<a href="src/ali_test_2/types/api/v2/order_relist_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customer_care_order.py">CustomerCareOrder</a></code>
- <code title="post /api/v2/orders/{id}/resendConfirmationEmail">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">resend_confirmation_email</a>(id, \*\*<a href="src/ali_test_2/types/api/v2/order_resend_confirmation_email_params.py">params</a>) -> None</code>
- <code title="get /api/v2/orders/{id}/applePasses">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">retrieve_apple_passes</a>(id) -> <a href="./src/ali_test_2/types/api/v2/order_retrieve_apple_passes_response.py">OrderRetrieveApplePassesResponse</a></code>
- <code title="get /api/v2/orders/{confirmationNumber}/customerCareInformation">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">retrieve_customer_care_information</a>(confirmation_number, \*\*<a href="src/ali_test_2/types/api/v2/order_retrieve_customer_care_information_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/customer_care_order.py">CustomerCareOrder</a></code>
- <code title="get /api/v2/orders/{id}/googlePasses">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">retrieve_google_passes</a>(id) -> <a href="./src/ali_test_2/types/api/v2/order_retrieve_google_passes_response.py">OrderRetrieveGooglePassesResponse</a></code>
- <code title="get /api/v2/orders/{id}/relistInfo">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">retrieve_relist_info</a>(id, \*\*<a href="src/ali_test_2/types/api/v2/order_retrieve_relist_info_params.py">params</a>) -> object</code>
- <code title="post /api/v2/orders/{id}/ticketProtectionRedemption">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">ticket_protection_redemption</a>(id, \*\*<a href="src/ali_test_2/types/api/v2/order_ticket_protection_redemption_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/order_ticket_protection_redemption_response.py">OrderTicketProtectionRedemptionResponse</a></code>
- <code title="patch /api/v2/orders/{id}/reclaim">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">update_reclaim</a>(id, \*\*<a href="src/ali_test_2/types/api/v2/order_update_reclaim_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/order.py">Order</a></code>
- <code title="post /api/v2/orders/{holdId}/void">client.api.v2.orders.<a href="./src/ali_test_2/resources/api/v2/orders/orders.py">void</a>(hold_id, \*\*<a href="src/ali_test_2/types/api/v2/order_void_params.py">params</a>) -> None</code>

#### Transfers

Types:

```python
from ali_test_2.types.api.v2.orders import TransferRetrieveResponse
```

Methods:

- <code title="post /api/v2/orders/{id}/transfers">client.api.v2.orders.transfers.<a href="./src/ali_test_2/resources/api/v2/orders/transfers.py">create</a>(id) -> <a href="./src/ali_test_2/types/api/v2/order.py">Order</a></code>
- <code title="get /api/v2/orders/{id}/transfers/{transferId}">client.api.v2.orders.transfers.<a href="./src/ali_test_2/resources/api/v2/orders/transfers.py">retrieve</a>(transfer_id, \*, id) -> <a href="./src/ali_test_2/types/api/v2/orders/transfer_retrieve_response.py">TransferRetrieveResponse</a></code>
- <code title="patch /api/v2/orders/{id}/transfers/{transferId}">client.api.v2.orders.transfers.<a href="./src/ali_test_2/resources/api/v2/orders/transfers.py">update</a>(transfer_id, \*, id, \*\*<a href="src/ali_test_2/types/api/v2/orders/transfer_update_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/order.py">Order</a></code>

### Retailers

Types:

```python
from ali_test_2.types.api.v2 import PspOption, RetailerLegacy, RetailerRetrieveResponse
```

Methods:

- <code title="get /api/v2/retailers/{retailerId}">client.api.v2.retailers.<a href="./src/ali_test_2/resources/api/v2/retailers.py">retrieve</a>(retailer_id) -> <a href="./src/ali_test_2/types/api/v2/retailer_retrieve_response.py">RetailerRetrieveResponse</a></code>
- <code title="get /api/v2/retailers/{retailerId}/pspOptions">client.api.v2.retailers.<a href="./src/ali_test_2/resources/api/v2/retailers.py">retrieve_psp_options</a>(retailer_id, \*\*<a href="src/ali_test_2/types/api/v2/retailer_retrieve_psp_options_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/psp_option.py">PspOption</a></code>

### Shows

Types:

```python
from ali_test_2.types.api.v2 import (
    Account,
    Media,
    MediaImage,
    MinifiedLocation,
    ProductType,
    Rewards,
    RushSettings,
    Show,
    ShowListResponse,
    ShowRetrieveDealsResponse,
)
```

Methods:

- <code title="get /api/v2/shows/{showId}">client.api.v2.shows.<a href="./src/ali_test_2/resources/api/v2/shows/shows.py">retrieve</a>(show_id, \*\*<a href="src/ali_test_2/types/api/v2/show_retrieve_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/show.py">Show</a></code>
- <code title="get /api/v2/shows">client.api.v2.shows.<a href="./src/ali_test_2/resources/api/v2/shows/shows.py">list</a>(\*\*<a href="src/ali_test_2/types/api/v2/show_list_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/show_list_response.py">ShowListResponse</a></code>
- <code title="get /api/v2/shows/deals">client.api.v2.shows.<a href="./src/ali_test_2/resources/api/v2/shows/shows.py">retrieve_deals</a>(\*\*<a href="src/ali_test_2/types/api/v2/show_retrieve_deals_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/show_retrieve_deals_response.py">ShowRetrieveDealsResponse</a></code>
- <code title="get /api/v2/shows/{showId}/rushSettings">client.api.v2.shows.<a href="./src/ali_test_2/resources/api/v2/shows/shows.py">retrieve_rush_settings</a>(show_id) -> <a href="./src/ali_test_2/types/api/v2/rush_settings.py">RushSettings</a></code>

#### LotterySettings

Types:

```python
from ali_test_2.types.api.v2.shows import LotterySettings
```

Methods:

- <code title="post /api/v2/shows/{showId}/lotterySettings/generateNewQuestion">client.api.v2.shows.lottery_settings.<a href="./src/ali_test_2/resources/api/v2/shows/lottery_settings.py">generate_new_question</a>(show_id) -> <a href="./src/ali_test_2/types/api/v2/shows/lottery_settings.py">LotterySettings</a></code>
- <code title="get /api/v2/shows/{showId}/lotterySettings">client.api.v2.shows.lottery_settings.<a href="./src/ali_test_2/resources/api/v2/shows/lottery_settings.py">retrieve_lottery_settings</a>(show_id) -> <a href="./src/ali_test_2/types/api/v2/shows/lottery_settings.py">LotterySettings</a></code>

#### Showtimes

Types:

```python
from ali_test_2.types.api.v2.shows import (
    AdmissionType,
    FeeSummary,
    Showtime,
    TicketInfo,
    ShowtimeListResponse,
    ShowtimeRetrieveInventoryItemsResponse,
    ShowtimeRetrieveSectionsResponse,
    ShowtimeRetrieveWithRushAvailabilityResponse,
)
```

Methods:

- <code title="get /api/v2/shows/{showId}/showtimes">client.api.v2.shows.showtimes.<a href="./src/ali_test_2/resources/api/v2/shows/showtimes.py">list</a>(show_id, \*\*<a href="src/ali_test_2/types/api/v2/shows/showtime_list_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/shows/showtime_list_response.py">ShowtimeListResponse</a></code>
- <code title="get /api/v2/shows/{showId}/showtimes/{showtimeId}/inventoryItems">client.api.v2.shows.showtimes.<a href="./src/ali_test_2/resources/api/v2/shows/showtimes.py">retrieve_inventory_items</a>(showtime_id, \*, show_id) -> <a href="./src/ali_test_2/types/api/v2/shows/showtime_retrieve_inventory_items_response.py">ShowtimeRetrieveInventoryItemsResponse</a></code>
- <code title="get /api/v2/shows/{id}/showtimes/{showtimeId}/sections">client.api.v2.shows.showtimes.<a href="./src/ali_test_2/resources/api/v2/shows/showtimes.py">retrieve_sections</a>(showtime_id, \*, id, \*\*<a href="src/ali_test_2/types/api/v2/shows/showtime_retrieve_sections_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/shows/showtime_retrieve_sections_response.py">ShowtimeRetrieveSectionsResponse</a></code>
- <code title="get /api/v2/shows/{showId}/showtimes/with_rush_availability">client.api.v2.shows.showtimes.<a href="./src/ali_test_2/resources/api/v2/shows/showtimes.py">retrieve_with_rush_availability</a>(show_id) -> <a href="./src/ali_test_2/types/api/v2/shows/showtime_retrieve_with_rush_availability_response.py">ShowtimeRetrieveWithRushAvailabilityResponse</a></code>

### ShowGroups

Types:

```python
from ali_test_2.types.api.v2 import ShowGroupRetrieveResponse, ShowGroupRetrieveShowGroupsResponse
```

Methods:

- <code title="get /api/v2/showGroups/{showGroupId}">client.api.v2.show_groups.<a href="./src/ali_test_2/resources/api/v2/show_groups.py">retrieve</a>(show_group_id) -> <a href="./src/ali_test_2/types/api/v2/show_group_retrieve_response.py">ShowGroupRetrieveResponse</a></code>
- <code title="get /api/v2/showGroups">client.api.v2.show_groups.<a href="./src/ali_test_2/resources/api/v2/show_groups.py">retrieve_show_groups</a>(\*\*<a href="src/ali_test_2/types/api/v2/show_group_retrieve_show_groups_params.py">params</a>) -> <a href="./src/ali_test_2/types/api/v2/show_group_retrieve_show_groups_response.py">ShowGroupRetrieveShowGroupsResponse</a></code>

# Views

## V2

Types:

```python
from ali_test_2.types.views import (
    HeroPromoView,
    HeroShowGroupView,
    HeroShowView,
    HeroView,
    V2ListHeroViewsResponse,
    V2RetrieveHeroFilterResponse,
)
```

Methods:

- <code title="get /views/v2/heroList">client.views.v2.<a href="./src/ali_test_2/resources/views/v2.py">list_hero_views</a>(\*\*<a href="src/ali_test_2/types/views/v2_list_hero_views_params.py">params</a>) -> <a href="./src/ali_test_2/types/views/v2_list_hero_views_response.py">V2ListHeroViewsResponse</a></code>
- <code title="get /views/v2/heroFilter">client.views.v2.<a href="./src/ali_test_2/resources/views/v2.py">retrieve_hero_filter</a>(\*\*<a href="src/ali_test_2/types/views/v2_retrieve_hero_filter_params.py">params</a>) -> <a href="./src/ali_test_2/types/views/v2_retrieve_hero_filter_response.py">V2RetrieveHeroFilterResponse</a></code>

# Feeds

## V2

Types:

```python
from ali_test_2.types.feeds import V2ListShowsResponse
```

Methods:

- <code title="get /feeds/v2/shows">client.feeds.v2.<a href="./src/ali_test_2/resources/feeds/v2.py">list_shows</a>(\*\*<a href="src/ali_test_2/types/feeds/v2_list_shows_params.py">params</a>) -> <a href="./src/ali_test_2/types/feeds/v2_list_shows_response.py">V2ListShowsResponse</a></code>
- <code title="get /feeds/v2/feed">client.feeds.v2.<a href="./src/ali_test_2/resources/feeds/v2.py">retrieve_feed</a>(\*\*<a href="src/ali_test_2/types/feeds/v2_retrieve_feed_params.py">params</a>) -> None</code>
